from abc import ABCMeta, abstractmethod
from enum import Enum

import numpy as np

from device.sig_chain.sig_buffer import CircularBuffer
from device.sig_chain.sig_buffer import ParserNewsetWithTime
from device.sig_chain.sig_save import SigSave


class Device(Enum):
    FAKER = 0
    PONY = 1
    NEO = 2


class DataMode(Enum):
    WAVE = 1
    IMPEDANCE = 2


# 使用 @dataclass 会导致pyindtaller打包失败，不要使用
class DataBlockInBuf:
    def __init__(self, data: np.ndarray, timestamp: int):
        self.data = data
        self.timestamp = timestamp  # ms


class Connector(metaclass=ABCMeta):

    def __del__(self):
        self.stop()

    def set_saver(self):
        SAVE_UNIT_SECONDS = 1
        assert SAVE_UNIT_SECONDS * 1000 >= self.sample_params.delay_milliseconds, \
            'Buffer size >= delay_milliseconds must be satisfied!'
        self.buffer_save = CircularBuffer(
            SAVE_UNIT_SECONDS, # edf 每次存储1s的数据
            self.sample_params.data_count_per_channel /
            self.sample_params.sample_rate, self.sample_params.channel_labels,
            self.sample_params.channel_types, self.sample_params.sample_rate,
            ParserNewsetWithTime())
        self.saver = SigSave(self.sample_params.channel_labels,
                             self.sample_params.sample_rate,
                             self.sample_params.physical_max,
                             self.sample_params.physical_min)

    def _save_data_when_buffer_full(self, data_block):
        if self.saver and self.buffer_save and self.saver.is_ready:
            self.buffer_save.update(data_block)
            ret = self.buffer_save.get_sig('array')
            if ret['status'] == 'ok':
                self.saver.save_raw_data(ret['data'], ret['timestamp'][0])

    @abstractmethod
    def load_config(self):
        return

    @abstractmethod
    def get_ready(self):
        return

    @abstractmethod
    def is_connected(self):
        return

    @abstractmethod
    def setup_wave_mode(self):
        return

    @abstractmethod
    def setup_impedance_mode(self):
        return

    @abstractmethod
    def receive_wave(self):
        return

    @abstractmethod
    def receive_impedance(self):
        return

    @abstractmethod
    def stop(self):
        return
