"""提供标准头模及电极信息。"""
from typing import List

import mne

class MontageBase():
    """根据EEG的10-20标准创建montge"""

    def __init__(self, chan_labels: List[str], chan_types: List[str], fs):
        """按mne的格式初始化数据info和montage

        Args:
            chan_labels (List[str]): 导联标签
            chan_types (List[str]): 可以是任意str，一般写为"eeg"即可，注意要对每个chan_labels都定义
            fs (float): 采样率
        """
        self.info = mne.create_info(chan_labels, ch_types=chan_types, sfreq=fs)
        self.info.set_montage("standard_1020")
        self.montage = self.info.get_montage()


    def print_montage_names(self):
        """列出mne内建的montage列表"""
        builtin_montages = mne.channels.get_builtin_montages(descriptions=True)
        for montage_name, montage_description in builtin_montages:
            print(f"{montage_name}: {montage_description}")


    # def load_montage(self, montage_name: str):
    #     """载入montage"""
    #     montage = mne.channels.make_standard_montage(montage_name)
    #     return montage


    def plot_montage(self):
        """依据输入的montage绘制脑地形图"""
        self.montage.plot()


    def get_chan_labels(self):
        """列出montage所有电极的标签"""
        return self.montage.ch_names


    def get_chan_positions(self):
        """列出montage所有电极的坐标"""
        return self.montage.get_positions()


    def find_label_by_chan(self, chan: int):
        """输入导联号返回对应的导联标签"""
        return self.montage.ch_names[chan]


    def find_chan_by_label(self, label: str):
        """输入导联标签返回对应的导联号"""
        chan_names = self.montage.ch_names
        return chan_names.index(label)
